
/*************************************************************************************************************************************************************************************************************************************************************************
* Program name:      		SubjShareValue.ado
* Program author:			Florian Peters, Finance Group, University of Amsterdam
* Date:             		August 2014

* Description: 				Creates a variable containing the subjective value of one (single) restricted share. The subjective value is computed according to the Ingersoll (2006) model and implements the formula given in equation (11) on p. 462 in Ingersoll (2006).
		
* Background & Application:	You may want to read the following papers:
							Ingersoll, Jonathan E., 2006, The subjective and objective evaluation of incentive stock options, The Journal of Business, vol. 79, no. 2, pp. 453-488.
							Peters, Florian S. and Alexander F. Wagner, 2014, The executive turnover risk premium, The Journal of Finance, vol. 69, no. 4, pp. 1529-1563.

* Usage:					You are free to use this program.  If you use it, please let us know: f.s.peters@uva.nl AND alexander.wagner@bf.uzh.ch

* Syntax:            		SubjShareValue  StockPrice StockVestingPeriod DividenRate RiskFreeRate ResidualVariance, rho(ValueOfCRRA) theta(ValueOfPortfolioConstraint) newvar(NameOfNewVariable)

* Variable definitions		StockPrice:			 			The stock price
							StockVestingPeriod:	 			The vesting period of the restricted share (in years)
							DividendRate: 		 			The dividend rate (in decimals) 
							RiskFreeRate: 		 			The risk free rate (in decimals)
							ResidualVariance: 	 			The variance of market model residuals or multi-factor model residuals (in decimals), see p. 458 in Ingersoll (2006)

* Parameter definitions		ValueOfCRRA:		 	 		The coefficient of relative risk aversion (this number cannot be set exactly to one)
							ValueOfPortfolioConstraint: 	The fraction of wealth that the manager is forced to hold in his firm's stock beyond what he would voluntarily hold, e.g. due to vesting restrictions. This number must be between 0 and 1.
							
**************************************************************************************************************************************************************************************************************************************************************************/


capture program drop SubjShareValue
program define SubjShareValue
	syntax varlist(numeric min=5 max=5) [if] [in], rho(real) theta(real) newvar(name)
	cap drop Keep
	quietly g Keep = 1 `if' `in'

	tokenize "`varlist'"
	local S         "`1'"
	local T         "`2'"
	local div       "`3'"
	local rf        "`4'"
	local varresid  "`5'"
		
	quietly g qhat           = `div'+`rho'*(1-`theta')*`theta'*`varresid'             if Keep==1
	quietly g `newvar'       = `S'*( `div'/qhat + exp(-qhat*`T')*(1-`div'/qhat) )     if Keep==1

	cap drop qhat
	cap drop rhat
	cap drop Keep
end
